[Xfce4-commits] [apps/xfdashboard] 02/04: Avoid closing windows accidently with key <Backspace>

noreply at xfce.org noreply at xfce.org
Tue Mar 24 10:25:20 CET 2015


This is an automated email from the git hooks/post-receive script.

nomad pushed a commit to annotated tag 0.2.3
in repository apps/xfdashboard.

commit 3306488d337775c0800a057354340b4a25e1a07d
Author: Stephan Haller <nomad at froevel.de>
Date:   Sat Aug 16 08:24:54 2014 +0200

    Avoid closing windows accidently with key <Backspace>
    
    A window can accidently be closed when starting a search by typing and correcting more letters than entered with key <Backspace>. Because then the view switchs from search view back to windows view, sets the focus to a window in the win$
    
    This commit addresses issue #32.
---
 src/windows-view.c |    9 ++++++++-
 1 file changed, 8 insertions(+), 1 deletion(-)

diff --git a/src/windows-view.c b/src/windows-view.c
index 171727e..ca27cca 100644
--- a/src/windows-view.c
+++ b/src/windows-view.c
@@ -831,7 +831,7 @@ static gboolean _xfdashboard_windows_view_focusable_handle_keyrelease_event(Xfda
 	self=XFDASHBOARD_WINDOWS_VIEW(inFocusable);
 	priv=self->priv;
 
 	/* Activate selected window on ENTER or close window on DELETE/BACKSPACE */
 	switch(inEvent->key.keyval)
 	{
 		case CLUTTER_KEY_Return:
@@ -844,6 +844,13 @@ static gboolean _xfdashboard_windows_view_focusable_handle_keyrelease_event(Xfda
 			return(CLUTTER_EVENT_STOP);
 
 		case CLUTTER_KEY_BackSpace:
+			if(clutter_event_has_shift_modifier(inEvent) &&
+				priv->selectedItem)
+			{
+				_xfdashboard_windows_view_on_window_close_clicked(self, XFDASHBOARD_LIVE_WINDOW(priv->selectedItem));
+			}
+			return(CLUTTER_EVENT_STOP);
+
 		case CLUTTER_KEY_Delete:
 		case CLUTTER_KEY_KP_Delete:
 			if(priv->selectedItem)
@@ -831,7 +831,7 @@ static gboolean _xfdashboard_windows_view_focusable_handle_keyrelease_event(Xfda
 	priv=self->priv;
 
-	/* Activate selected window on ENTER or close window on DELETE/BACKSPACE */
+	/* Activate selected window on ENTER or close window on DELETE/SHIFT+BACKSPACE */
 	switch(inEvent->key.keyval)
 	{

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list